@@ -7,9 +7,9 @@
  * Support : support@synerty.com
 """
 
-rapuiServerEcho = 'rapuiServerEcho'
-rapuiClientEcho = 'rapuiClientEcho'
-rapuiVortexUuid = 'rapuiVortexUuid'
+rapuiServerEcho = "rapuiServerEcho"
+rapuiClientEcho = "rapuiClientEcho"
+rapuiVortexUuid = "rapuiVortexUuid"
 
 plIdKey = "id"
 plDeleteKey = "delete"
