@@ -8,12 +8,13 @@
 """
 import inspect
 import json
+import logging
 import re
-from abc import ABCMeta, abstractmethod, ABC
+from abc import abstractmethod, ABC
 from copy import deepcopy
 from datetime import datetime
 from time import strptime
-from typing import Dict, Optional, Annotated, Any
+from typing import Dict, Optional, Annotated
 from typing import List
 from typing import Type
 from typing import get_args
@@ -31,9 +32,12 @@ from .SerialiseUtil import T_RAPUI_TUPLE
 from .SerialiseUtil import WKBElement
 from .SerialiseUtil import convertFromWkbElement
 
-TUPLE_TYPES = []
-TUPLE_TYPES_BY_NAME: Dict[str, "Tuple"] = {}
-TUPLE_TYPES_BY_SHORT_NAME: Dict[str, "Tuple"] = {}
+logger = logging.getLogger(__name__)
+
+
+TUPLE_TYPES: list[Type["Tuple"]] = []
+TUPLE_TYPES_BY_NAME: Dict[str, Type["Tuple"]] = {}
+TUPLE_TYPES_BY_SHORT_NAME: Dict[str, Type["Tuple"]] = {}
 
 JSON_EXCLUDE = "jsonExclude"
 
@@ -119,7 +123,6 @@ def addTupleType(cls):
     fields = []
     shortFieldNames = set()
     for name, value in objDict.items():
-
         if isinstance(value, TupleField):
             shortName = value.shortName if value.shortName else name
 
@@ -138,19 +141,23 @@ def addTupleType(cls):
         if shortName.startswith("_"):
             underscoreException()
 
-        value.name = name
-        fields.append(name)
+        if isinstance(value, InstrumentedAttribute):
+            assert value.name is not None, "InstrumentedAttribute.name is None"
+        else:
+            value.name = name
+
+        fields.append(value.name)
 
         if shortName != JSON_EXCLUDE:
             if shortName in shortFieldNames:
                 raise Exception(
-                    "TupleField %s short name %s is alread registered"
+                    "TupleField %s short name %s is already registered"
                     % (name, shortName)
                 )
 
             shortFieldNames.add(shortName)
 
-    hasSlots = hasattr(cls, "__slots__")
+    hasSlots = len(getattr(cls, "__slots__", ())) > 0
     hasFieldNames = cls.__fieldNames__ is not None
 
     if hasSlots and hasFieldNames:
@@ -305,7 +312,6 @@ class _TupleToSqlaJsonMixin:
         insertDict = {}
 
         for field in self.__class__.__dict__.values():
-
             if not isinstance(field, InstrumentedAttribute):
                 continue
 
@@ -411,7 +417,6 @@ class _TupleToPlainJsonMixin:
     def __tupleToJsonDict(
         self, includeNones=True, includeFalse=True, useShortNames=True
     ):
-
         if useShortNames:
             json = {
                 "_tt": (
@@ -496,7 +501,7 @@ class _TupleToPlainJsonMixin:
             #     return convertFromWkbElement(value)
 
             if isinstance(value, str) and re.match(ISO8601_REGEXP, value):
-                return strptime(value, ISO8601)
+                return datetime.strptime(value, ISO8601)
 
             return value
 
@@ -552,7 +557,6 @@ class _TupleToPlainJsonMixin:
             return extraTypeHit
 
         def getFieldValidatorFromExtraHint(extraTypeHint):
-
             origin = get_origin(extraTypeHint)
 
             # Check if the type hint is an Annotated
@@ -608,14 +612,18 @@ class _TupleToPlainJsonMixin:
             extraTypeHint = getExtraTypeHint(fieldName)
             validator = getFieldValidatorFromExtraHint(extraTypeHint)
 
+            if (
+                isinstance(value, str)
+                and datetime is typeHint
+                and re.match(ISO8601_REGEXP, value)
+            ):
+                return datetime.strptime(value, ISO8601)
+
             raiseIfNotType(fieldName, typeHint, value, validator)
 
             if value in (None, ""):
                 return value
 
-            if isinstance(value, str) and re.match(ISO8601_REGEXP, value):
-                return strptime(value, ISO8601)
-
             if isinstance(value, list):
                 listItemTypeHint = get_args(typeHint)[0]
                 listItemTypeValidator = getFieldValidatorFromExtraHint(
@@ -691,13 +699,23 @@ class _TupleToPlainJsonMixin:
                         valueTypeExtraHint
                     )
 
+                    logger.warning(
+                        f"typing is not checked for key 'key' in value '{value}'"
+                    )
                     for key, item in value.items():
-                        raiseIfNotType(
-                            fieldName, keyTypeHint, key, keyTypeValidator
-                        )
-                        raiseIfNotType(
-                            fieldName, valueTypeHint, item, valueTypeValidator
-                        )
+                        # raiseIfNotType(
+                        #     fieldName, keyTypeHint, key, keyTypeValidator
+                        # )
+                        # raiseIfNotType(
+                        #     fieldName, valueTypeHint, item, valueTypeValidator
+                        # )
+
+                        # this should be in SerialiseUtil.py
+                        if isinstance(item, str) and re.match(
+                            ISO8601_REGEXP, item
+                        ):
+                            item = datetime.strptime(item, ISO8601)
+
                         data[key] = item  # No change
 
                 return data
@@ -746,7 +764,7 @@ class Tuple(Jsonable, _TupleToPlainJsonMixin, _TupleToSqlaJsonMixin):
         Jsonable.__init__(self)
 
         # If we're using slots, then don't use tuple fields (there arn't any anyway)
-        if hasattr(self.__class__, "__slots__"):
+        if getattr(self.__class__, "__slots__", None):
             # noinspection PyTypeChecker
             for key in self.__class__.__slots__:
                 if key in kwargs:
