@@ -136,6 +136,13 @@ class TupleDataObservableHandler:
     def hasTupleSubscribers(self, tupleSelector: TupleSelector):
         return tupleSelector.toJsonStr() in self._observerDataByTupleSelector
 
+    def tupleSubscribers(self) -> List[TupleSelector]:
+        # This is a bit costly
+        return [
+            TupleSelector.fromJsonStr(jsonStr)
+            for jsonStr in self._observerDataByTupleSelector
+        ]
+
     def shutdown(self):
         self._endpoint.shutdown()
         self._tupleSelectorUpdateMappers = []
@@ -156,6 +163,11 @@ class TupleDataObservableHandler:
                 tupleProvider.makeVortexMsg, filt, tupleSelector
             )
         except Exception as e:
+            logger.error(
+                f"createVortexMsg"
+                f" TupleSelector = {tupleSelector.toJsonStr()},"
+                f" ObservableFilt = {self._filt}"
+            )
             logger.exception(e)
             raise
         if not vortexMsg:
@@ -235,12 +247,16 @@ class TupleDataObservableHandler:
         try:
             yield sendResponse(vortexMsg)
         except Exception as e:
+            logger.error(
+                f"_process"
+                f" TupleSelector = {tupleSelector.toJsonStr()},"
+                f" ObservableFilt = {self._filt}"
+            )
             logger.exception(e)
 
     def _getMappedTupleSelectors(
         self, tupleSelector: TupleSelector
     ) -> List[TupleSelector]:
-
         # Get all tuple selectors
         allTupleSelectors = [
             data.tupleSelector
@@ -267,7 +283,7 @@ class TupleDataObservableHandler:
         """Notify Of Tuple Update
 
         This method tells the observable that an update has occurred and that it should
-        send new data to it's observers.
+        send new data to its observers.
 
         Tuple selectors should be identical to the data being observed.
 
